;;; $DOOMDIR/config.el -*- lexical-binding: t; -*-

(load! "config/+priv-config")
;(load! "config/+centaur-tabs-config") ;; enable this config if :ui tabs
;(load! "config/+termux-config") ;; enable if termux

(setq doom-font (font-spec :family "DejaVu Sans Mono" :size 12)
      ;doom-variable-pitch-font (font-spec :family "IBM Plex Serif" :size 15))
      doom-variable-pitch-font (font-spec :family "Libertinus Serif" :size 15))
      ;doom-variable-pitch-font (font-spec :family "IBM Plex Sans" :size 15))

;;; LOOKS


;; favorite themes
(setq doom-theme
      ;'doom-tomorrow-night
      'doom-tomorrow-night-r
      ;'doom-one
      ;'doom-wilmersdorf
      ;'doom-monokai-ristretto
      ;'doom-plain-dark
      ;'doom-feather-dark

      ;; light themes
      ;'doom-plain
      ;'doom-flatwhite
      ;'leuven
      )

;; doom dashboard
;; remove useless dashboard info
(remove-hook '+doom-dashboard-functions #'doom-dashboard-widget-shortmenu)
(add-hook! '+doom-dashboard-mode-hook (hide-mode-line-mode 1) (hl-line-mode -1))
(setq-hook! '+doom-dashboard-mode-hook evil-normal-state-cursor (list nil))

;; opacity
(set-frame-parameter (selected-frame) 'alpha-background 80) (add-to-list 'default-frame-alist '(alpha-background . 80))

;; enable variable-pitch-mode for texts
;(add-hook 'text-mode-hook
;           (lambda ()
;            (variable-pitch-mode 1)))

(after! org
  (setq display-line-numbers-type nil
        org-hide-emphasis-markers t
        org-pretty-entities t
        org-ellipsis "…"
        org-image-actual-width 600))
(setq display-line-numbers-type nil)

;;; dont really use org-modern anymore but it might be useful for reference
;(use-package! org-modern
;  :init
;  ;(add-hook 'doom-post-init-hook (global-org-modern-mode))
;  :config
;  (setq org-modern-priority-faces
;        '((?A :inherit error
;              :inverse-video t)
;          (?B :inherit warning
;              :inverse-video t)
;          (?C :inherit success
;              :inverse-video t)
;          (?D :inherit error
;              :inverse-video t)
;          (?E :inherit warning
;              :inverse-video t)
;          (?F :inherit success
;              :inverse-video t))))

;; show time
;(setq display-time-format "%F %I:%M:%S"
;      display-time-interval 1
;      display-time-default-load-average nil)
;(add-hook 'doom-post-init-hook (display-time))

;; disable flyspell-mode
(after! flyspell
  (setq-default spell-checking-enable-by-default nil))

;; disable gutter for org-mode
(after! git-gutter
  (setq git-gutter:disabled-modes '(fundamental-mode image-mode pdf-view-mode org-mode)))

;; diary / journal
(after! org-journal
  (setq org-journal-dir "~/diary"
        org-journal-date-prefix "#+TITLE: "
        org-journal-time-prefix "+ "
        org-journal-date-format "%a, %Y-%m-%d"
        org-journal-file-format "%Y-%m-%d.org"))

;; reading list
(use-package! org-books
  :defer t
  :config
  (setq org-books-file "~/notebook/readinglist.org"))

;;; org settings
(setq org-directory "~/notebook/"
      bookmark-default-file "~/.config/doom/bookmarks")
(load! "config/+org-capture-config")
(load! "config/+org-roam-config")
(load! "config/+org-wild-notifier-config")
(load! "config/+org-pomodoro-config")

(after! org
  (setq org-log-done 'time
        org-log-into-drawer t
        ;About the 2 elisp lines below: If you want to send items without explicit
        ;priorities to the bottom of the list you have to set org-default-priority to the
        ;value of org-lowest-priority). I did this to make recognize that: PRIORITY=0 are
        ;items without explicit priorities (not A, B or C, but just TODO)
        org-lowest-priority ?E
        org-default-priority ?E)
  (defun jethro/org-archive-done-tasks ()
    "Archive all done tasks."
    (interactive)
    (org-map-entries 'org-archive-subtree "/DONE" 'file)))


;;; agenda, todos

(setq org-agenda-files '("~/housekeeping/calendar.org"
                         "~/notebook/ag/"                ;; todo.org and habits.org shorthand for agendas
                         "~/notebook/refile.org"
                         "~/notebook/notes/events/birthdays.org"))

(after! org-agenda
  (setq org-agenda-sticky t)) ; dont kill agendas

; note that eisenhower matrix and agenda commands below and mappings for them
; assumes that you've tagged them correctly, basically:
; 1. :habits: :daily_tasks:
; - only purpose of this is for filtering them out
;   - :habits: are for all recurring tasks
;   - :daily_tasks: are for everyday tasks
; 2. :todo:
; - will be included in the eisenhower matrix
;   priorities are #A, #B, #C, #D/not-set/other
;   for urgency and importancy levels
;
; the view "Schedule/Eisenhower-List" is for both tracking scheduled tasks (:habits:) and
; :todo:'s that are not scheduled but categorized with a priority (e.g. [#A])
; using this view should be enough for what i need

(load! "config/+eisenhower-matrix-list")

(load! "config/+eisenhower-matrix")

(load! "config/+todo-workspaces")

(defun agenda/hide-daily-tasks (&optional arg)
  (interactive "P")
  (let ((org-agenda-tag-filter-preset '("-daily_tasks")))
   (org-agenda arg "a")))
(defun agenda/hide-habits (&optional arg)
  (interactive "P")
  (let ((org-agenda-tag-filter-preset '("-habits")))
   (org-agenda arg "a")))
(defun agenda/hide-todos (&optional arg)
  (interactive "P")
  (let ((org-agenda-tag-filter-preset '("-todo")))
   (org-agenda arg "a")))

(map! :leader
      (:prefix-map ("o" . "open")
       (:prefix ("a" . "org agenda")
        :desc "Eisenhower Matrix"           "e" #'+eisenhower-matrix/make-eisenhower-matrix ;; classic eisenhower matrix
        (:prefix-map ("h" . "hide filter agenda")
         :desc "Agenda without daily tasks" "d"  #'agenda/hide-daily-tasks
         :desc "Agenda without habits"      "h"  #'agenda/hide-habits
         :desc "Agenda without todo"        "t"  #'agenda/hide-todos
         :desc "Just agenda"                "a"  #'org-agenda-list) ;; TODO reset keybind
        (:prefix-map ("w" . "workspaces")
         :desc "Eisenhower Matrix"               "e" #'+eisenhower-matrix/make-eisenhower-matrix ;; classic eisenhower matrix
         :desc "Schedule/Eisenhower-list/todo"   "t"  #'+todo-workspaces/make-todo-workspace
         :desc "Schedule/Eisenhower-list"        "s"  #'+todo-workspaces/make-todo-workspace-min)
        )))

(map! :leader
      (:prefix-map ("o" . "open")
       (:prefix-map ("w" . "workspaces")
        :desc "Eisenhower Matrix"           "e" #'+eisenhower-matrix/make-eisenhower-matrix ;; classic eisenhower matrix
        :desc "Schedule/Eisenhower-list/todo"   "t"  #'+todo-workspaces/make-todo-workspace
        :desc "Schedule/Eisenhower-list"        "s"  #'+todo-workspaces/make-todo-workspace-min)
        ))

;;; copying images into org
(after! org-download
  (setq-default
   org-download-method 'directory
   ;; org-download-screenshot-method "grimshot save window %s"
   ;; org-download-screenshot-method "wl-paste -t image/png > '%s'"
   ;; below script is available on dotfiles: ../.local/bin
   org-download-screenshot-method "convert-paste-png.sh '%s'"
   org-download-abbreviate-filename-function 'concat
   org-download-image-dir "~/notebook/images/org-download"
   org-download-heading-lvl nil
   org-download-timestamp "%Y%m%d-%H%M%S_")
  (add-hook 'dired-mode-hook 'org-download-enable)
  (map! :leader
        (:prefix ("i". "insert")
         :desc "insert image from clipboard" "Y" #'org-download-screenshot)))

;;; reading epubs
(use-package! nov
  :mode ("\\.epub\\'" . nov-mode)
  :config
  (setq nov-save-place-file (concat doom-cache-dir "nov-places")
        ;nov-text-width t
        ;nov-text-width 80
        ;nov-variable-pitch nil
        )
  ;(advice-add 'nov-render-title :override #'ignore)
  ;(defun +nov-mode-setup ()
    ;(variable-pitch-mode 1)
    ;(hide-mode-line-mode 1)
    ;(require 'visual-fill-column nil t)
    ;(setq-local visual-fill-column-center-text t)
    ;(setq-local visual-fill-column-width 91)
    ;)
  ;(add-hook 'nov-mode-hook #'+nov-mode-setup)
  (add-hook 'nov-mode-hook 'visual-line-mode)
  (add-hook 'nov-mode-hook 'variable-pitch-mode)
  ;(add-hook 'nov-mode-hook 'visual-fill-column-mode)
  )

;;; org-publish (wip)
(setq org-publish-use-timestamps-flag nil
      org-export-with-broken-links t
      org-html-link-org-files-as-html t
      org-html-link-use-abs-url t
      org-html-validation-link nil            ;; Don't show validation link
      ;org-html-head-include-scripts nil       ;; Use our own scripts
      ;org-html-head-include-default-style nil ;; Use our own styles
      ;org-html-head "<link rel=\"stylesheet\" href=\"https://cdn.simplecss.org/simple.min.css\" />"
      org-html-head "<link rel=\"stylesheet\" href=\"/style.css\" /><link rel=\"stylesheet\" href=\"/syntax.css\" />"
      org-publish-project-alist
      (list
       (list "org-site:main"
             :recursive t
             :base-directory "~/notebook/blog/"
             :publishing-directory "~/output/public"
             :publishing-function 'org-html-publish-to-html
             :with-author nil
             :with-creator t
             :with-toc nil
             :html-link-use-abs-url t
             :exclude "default.org"
             :section-numbers nil
             :with-timestamps nil)
       (list "org-site:assets"
             :base-directory "~/notebook/blog/"
             :base-extension "css\\|js\\|png\\|jpg\\|gif\\|pdf\\|mp3\\|ogg\\|woff2\\|ttf"
             :publishing-directory "~/output/public"
             :recursive t
             :publishing-function 'org-publish-attachment)))

(defvar dw/site-url (if (string-equal (getenv "CI") "true")
                        "https://example.org"
                      "http://localhost:8080")
  "The URL for the site being generated.")

(setq webfeeder-title-function 'webfeeder-title-libxml
      webfeeder-date-function 'webfeeder-date-libxml)

(defun my/org-publish ()
  "publish all including rss"
    (interactive)
 (start-process-shell-command "delete public html directory" nil "rm -r ~/output/public/*")
 (org-publish-all t)
 (webfeeder-build "rss.xml"
                  "~/output/public"
                  dw/site-url
                  (let ((default-directory (expand-file-name "~/output/public/")))
                       (directory-files-recursively default-directory
                                                    ".*\\.html$"))
                  :builder 'webfeeder-make-rss
                  :title "Rss"
                  :description "Rss"
                  :author "John Doe")
 (message "Build complete"))
(defun my/http-serve-blog ()
  (interactive)
  (httpd-serve-directory "~/output/public")
  (start-process-shell-command "open browser" nil "$BROWSER http://localhost:8080")
 ;(start-process-shell-command "Start http server at public html directory" nil "http-server ~/output/public/")
 )
(defun my/blog-refresh ()
  (interactive)
  (my/org-publish)
  (httpd-stop)
  (my/http-serve-blog))
